@@ -48,7 +48,7 @@ import operator
 from six import StringIO
 
 from lark import Lark
-from lark import Tree, Transformer, Visitor
+from lark import Tree, Visitor
 
 from particle import Particle
 from particle.converters import PDG2EvtGenNameMap
@@ -1390,61 +1390,3 @@ def get_global_photos_flag(parsed_file):
         return PhotosEnum.yes if val == "yes" else PhotosEnum.no
     except Exception:
         RuntimeError("Input parsed file does not seem to have the expected structure.")
-
-
-class TreeToDec(Transformer):
-    def yes(self, items):
-        return True
-
-    def no(self, items):
-        return False
-
-    def global_photos(self, items):
-        (item,) = items
-        return PhotosEnum.yes if item else PhotosEnum.no
-
-    def value(self, items):
-        (item,) = items
-        return float(item)
-
-    def label(self, items):
-        (item,) = items
-        return str(item)
-
-    def photos(self, items):
-        return PhotosEnum.yes
-
-
-def define(transformed):
-    return {x.children[0]: x.children[1] for x in transformed.find_data("define")}
-
-
-def pythia_def(transformed):
-    return [x.children for x in transformed.find_data("pythia_def")]
-
-
-def alias(transformed):
-    return {x.children[0]: x.children[1] for x in transformed.find_data("alias")}
-
-
-def chargeconj(transformed):
-    return {x.children[0]: x.children[1] for x in transformed.find_data("chargeconj")}
-
-
-# Commands
-def global_photos(transformed):
-    return {
-        x.children[0]: x.children[1] for x in transformed.find_data("global_photos")
-    }
-
-
-def decay(transformed):
-    return Tree("decay", list(transformed.find_data("decay")))
-
-
-def cdecay(transformed):
-    return [x.children[0] for x in transformed.find_data("cdecay")]
-
-
-def setlspw(transformed):
-    return list(transformed.find_data("setlspw"))
