@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2018-2020, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/decaylanguage for details.
@@ -21,6 +21,6 @@ DIR = Path(__file__).parent.resolve()
 def test_full_convert():
     text = ampgen2goofit(DIR / "../models/DtoKpipipi_v2.txt", ret_output=True)
     with (DIR / "output/DtoKpipipi_v2.cu").open() as f:
-        assert set(
-            x.strip() for x in text.splitlines() if "Generated on" not in x
-        ) == set(x.strip() for x in f.readlines() if "Generated on" not in x)
+        assert {x.strip() for x in text.splitlines() if "Generated on" not in x} == {
+            x.strip() for x in f.readlines() if "Generated on" not in x
+        }
